@@ -13,7 +13,7 @@ from collections import Mapping, defaultdict
 from operator import itemgetter
 from copy import deepcopy
 
-from .utils import (
+from label_studio_converter.utils import (
     parse_config, create_tokens_and_tags, download, get_image_size, get_image_size_and_channels, ensure_dir
 )
 
@@ -27,6 +27,7 @@ class FormatNotSupportedError(NotImplementedError):
 
 class Format(Enum):
     JSON = auto()
+    JSON_MIN = auto()
     CSV = auto()
     TSV = auto()
     CONLL2003 = auto()
@@ -61,7 +62,9 @@ class Converter(object):
         if isinstance(format, str):
             format = Format.from_string(format)
         if format == Format.JSON:
-            self.convert_to_json(input_data, output_data, is_dir=is_dir)
+            self.convert_to_json(input_data, output_data)
+        elif format == Format.JSON_MIN:
+            self.convert_to_json_min(input_data, output_data, is_dir=is_dir)
         elif format == Format.CSV:
             header = kwargs.get('csv_header', True)
             sep = kwargs.get('csv_separator', ',')
@@ -86,8 +89,9 @@ class Converter(object):
             for tag in output_tags:
                 if tag not in self._schema:
                     logger.warning(
-                        f'Specified tag "{tag}" not found in config schema: '
-                        f'available options are {list(self._schema.keys())}')
+                        'Specified tag "{tag}" not found in config schema: '
+                        'available options are {schema_keys}'.format(
+                            tag=tag, schema_keys=str(list(self._schema.keys()))))
         for name, info in self._schema.items():
             if output_tags is not None and name not in output_tags:
                 continue
@@ -96,15 +100,29 @@ class Converter(object):
                 data_keys |= new_data_keys
             if data_keys != new_data_keys and output_tags is None:
                 raise ValueError(
-                    f'Input schema for tag {name} differs from other tags: can\'t resolve data keys ambiguity. '
-                    f'Check your input tag {json.dumps(info["inputs"], indent=2)}, or explicitly specify which '
-                    f'output tag you wan\'t to save by using "output_tag" option')
+                    'Input schema for tag {name} differs from other tags: can\'t resolve data keys ambiguity. '
+                    'Check your input tag {input_tags}, or explicitly specify which '
+                    'output tag you wan\'t to save by using "output_tag" option'.format(
+                        name=name, input_tags=json.dumps(info['inputs'], indent=2)))
             output_tag_names.append(name)
 
         return list(data_keys), output_tag_names
 
     def _get_supported_formats(self):
-        return [f.name for f in Format]
+        output_tag_types = set()
+        input_tag_types = set()
+        for info in self._schema.values():
+            output_tag_types.add(info['type'])
+            for input_tag in info['inputs']:
+                input_tag_types.add(input_tag['type'])
+
+        all_formats = [f.name for f in Format]
+        if not ('Text' in input_tag_types and 'Labels' in output_tag_types):
+            all_formats.remove(Format.CONLL2003.name)
+        if not ('Image' in input_tag_types and 'RectangleLabels' in output_tag_types):
+            all_formats.remove(Format.COCO.name)
+            all_formats.remove(Format.VOC.name)
+        return all_formats
 
     @property
     def supported_formats(self):
@@ -112,7 +130,7 @@ class Converter(object):
 
     def iter_from_dir(self, input_dir):
         if not os.path.exists(input_dir):
-            raise FileNotFoundError(f'{input_dir} doesn\'t exist')
+            raise FileNotFoundError('{input_dir} doesn\'t exist'.format(input_dir=input_dir))
         for json_file in glob(os.path.join(input_dir, '*.json')):
             for item in self.iter_from_json_file(json_file):
                 yield item
@@ -134,12 +152,13 @@ class Converter(object):
         if 'completions' in d:
             if len(d['completions']) != 1:
                 raise NotImplementedError(
-                    f'Currently only one completion could be added per task - we can\'t convert more than one completions, '
-                    f'but {len(d["completions"])} found in item: {json.dumps(d, indent=2)}')
+                    'Currently only one completion could be added per task - '
+                    'we can\'t convert more than one completions, but {num_completions} found in item: {item}'.format(
+                        num_completions=len(d['completions']), item=json.dumps(d, indent=2)))
             result = d['completions'][0]['result']
         elif 'result' in d:
             result = d['result']
-        inputs = {key: d['data'][key] for key in self._data_keys}
+        inputs = d['data']
         outputs = defaultdict(list)
         for r in result:
             if r['from_name'] in self._output_tags:
@@ -153,34 +172,42 @@ class Converter(object):
 
     def _check_format(self, fmt):
         pass
-        # if fmt not in self._supported_formats:
-        #     raise FormatNotSupportedError(
-        #         f'{fmt.name} format not supported for current config. Available options are: {self._supported_formats}')
 
     def _prettify(self, v):
-        if len(v) == 1:
-            v = v[0]
-            if v['type'] == 'Choices' and len(v['choices']) == 1:
-                return v['choices'][0]
-        else:
-            out = []
-            for i in v:
-                j = deepcopy(i)
-                j.pop('type')
+        out = []
+        for i in v:
+            j = deepcopy(i)
+            tag_type = j.pop('type')
+            if tag_type == 'Choices' and len(j['choices']) == 1:
+                out.append(j['choices'][0])
+            else:
                 out.append(j)
-            return out
+        return out[0] if len(out) == 1 else out
 
-    def convert_to_json(self, input_data, output_dir, is_dir=True):
+    def convert_to_json(self, input_dir, output_dir):
         self._check_format(Format.JSON)
         ensure_dir(output_dir)
         output_file = os.path.join(output_dir, 'result.json')
         records = []
+        for json_file in glob(os.path.join(input_dir, '*.json')):
+            with io.open(json_file) as f:
+                records.append(json.load(f))
+
+        with io.open(output_file, mode='w') as fout:
+            json.dump(records, fout, indent=2, ensure_ascii=False)
+
+    def convert_to_json_min(self, input_data, output_dir, is_dir=True):
+        self._check_format(Format.JSON_MIN)
+        ensure_dir(output_dir)
+        output_file = os.path.join(output_dir, 'result.json')
+        records = []
         item_iterator = self.iter_from_dir if is_dir else self.iter_from_json_file
         for item in item_iterator(input_data):
             record = deepcopy(item['input'])
             for name, value in item['output'].items():
                 record[name] = self._prettify(value)
             records.append(record)
+
         with io.open(output_file, mode='w') as fout:
             json.dump(records, fout, indent=2)
 
@@ -214,7 +241,7 @@ class Converter(object):
                     spans=next(iter(item['output'].values()))
                 )
                 for token, tag in zip(tokens, tags):
-                    fout.write(f'{token} -X- _ {tag}\n')
+                    fout.write('{token} -X- _ {tag}\n'.format(token=token, tag=tag))
                 fout.write('\n')
 
     def convert_to_coco(self, input_data, output_dir, output_image_dir=None, is_dir=True):
@@ -234,14 +261,16 @@ class Converter(object):
         item_iterator = self.iter_from_dir(input_data) if is_dir else self.iter_from_json_file(input_data)
         for item_idx, item in enumerate(item_iterator):
             if not item['output']:
-                logger.warning(f'No completions found for item #{item_idx}')
+                logger.warning('No completions found for item #' + str(item_idx))
                 continue
             image_path = item['input'][data_key]
             if not os.path.exists(image_path):
                 try:
                     image_path = download(image_path, output_image_dir)
                 except:
-                    logger.error(f'Unable to download {image_path}. The item {item} will be skipped', exc_info=True)
+                    logger.error('Unable to download {image_path}. The item {item} will be skipped'.format(
+                        image_path=image_path, item=item
+                    ), exc_info=True)
                     continue
             width, height = get_image_size(image_path)
             image_id = len(images)
@@ -311,7 +340,7 @@ class Converter(object):
         item_iterator = self.iter_from_dir(input_data) if is_dir else self.iter_from_json_file(input_data)
         for item_idx, item in enumerate(item_iterator):
             if not item['output']:
-                logger.warning(f'No completions found for item #{item_idx}')
+                logger.warning('No completions found for item #' + str(item_idx))
                 continue
             image_path = item['input'][data_key]
             annotations_dir = os.path.join(output_dir, 'Annotations')
@@ -321,7 +350,8 @@ class Converter(object):
                 try:
                     image_path = download(image_path, output_image_dir)
                 except:
-                    logger.error(f'Unable to download {image_path}. The item {item} will be skipped', exc_info=True)
+                    logger.error('Unable to download {image_path}. The item {item} will be skipped'.format(
+                        image_path=image_path, item=item), exc_info=True)
                     continue
             width, height, channels = get_image_size_and_channels(image_path)
             image_name = os.path.splitext(os.path.basename(image_path))[0]
